@@ -334,21 +334,12 @@ impl Kubectl {
         Ok(())
     }
 
-    pub(crate) async fn install_statehub_cluster(
-        &self,
-        namespace: &str,
-        install_state_crd: bool,
-    ) -> anyhow::Result<()> {
+    pub(crate) async fn install_statehub_cluster(&self, namespace: &str) -> anyhow::Result<()> {
         let crd = self.create_statehub_cluster_crd().await?;
         log::debug!("Created StatehubCluster CRD: {:#?}", crd);
         let cluster = self.create_statehub_cluster(namespace).await?;
         log::debug!("Created StatehubCluster: {:#?}", cluster);
 
-        if install_state_crd {
-            let crd = self.create_statehub_state_crd().await?;
-            log::debug!("Created State CRD: {:#?}", crd);
-        }
-
         let client = self.get_client().await?;
         let statehub_kubectl = statehub_cluster_operator::cluster::Kubectl::new(client);
         let namespace = statehub_kubectl.ensure_namespace_exists(&cluster).await?;
@@ -369,8 +360,6 @@ impl Kubectl {
     }
 
     pub(crate) async fn cleanup_statehub_cluster(&self) -> anyhow::Result<()> {
-        self.delete_statehub_state_crd().await?;
-        log::debug!("Deleted Statehub State CRD");
         self.delete_statehub_cluster_crd().await?;
         log::debug!("Deleted StatehubCluster CRD");
         Ok(())
