@@ -8,7 +8,7 @@ use std::fmt;
 use std::io;
 
 use anyhow::Context;
-use console::Term;
+use console::{Style, Term};
 use dialoguer::{theme, Confirm, Input};
 use futures::StreamExt;
 use itertools::Itertools;
@@ -159,9 +159,6 @@ enum Command {
         )]
         no_state: bool,
 
-        #[structopt(help = "Skip installing state CRD", long)]
-        no_state_crd: bool,
-
         #[structopt(
             help = "Skip setting up default storage class",
             long,
@@ -647,7 +644,6 @@ impl Cli {
                 contexts,
                 states,
                 no_state,
-                no_state_crd,
                 no_default_storage_class,
                 default_storage_class,
                 no_state_owner,
@@ -675,7 +671,6 @@ impl Cli {
                 };
 
                 let states = if no_state { None } else { Some(states) };
-                let install_state_crd = !no_state_crd;
                 let claim_unowned_states = !no_state_owner;
 
                 let helm = k8s::Helm::new(skip_helm);
@@ -690,7 +685,6 @@ impl Cli {
                     default_state,
                     claim_unowned_states,
                     cleanup_grace,
-                    install_state_crd,
                     azure,
                 );
                 if interactive {
@@ -843,6 +837,7 @@ pub(crate) struct StateHub {
     api: api::Api,
     stdout: Term,
     stderr: Term,
+    style: Style,
     theme: theme::SimpleTheme,
     json: bool,
     verbose: bool,
@@ -857,12 +852,14 @@ impl StateHub {
         let stdout = Term::stdout();
         let stderr = Term::stderr();
         let theme = theme::SimpleTheme;
+        let style = config.style();
 
         Self {
             config,
             api,
             stdout,
             stderr,
+            style,
             theme,
             json,
             verbose,
@@ -923,22 +920,22 @@ impl StateHub {
         self.api
             .create_state(state)
             .await
-            .print(&self.stdout, self.json)
+            .print(&self.stdout, &self.style, self.json)
     }
 
     async fn delete_state(&self, name: v0::StateName) -> anyhow::Result<()> {
         self.api
             .delete_state(name)
             .await
-            .print(&self.stdout, self.json)
+            .print(&self.stdout, &self.style, self.json)
     }
 
     async fn show_state(self, state: &v0::StateName) -> anyhow::Result<()> {
         let state = self.api.get_state(state).await.map(Detailed)?;
         if let Ok(clusters) = self.api.get_all_clusters().await {
-            StateAndClusters::new(state, clusters).print(&self.stdout, self.json)
+            StateAndClusters::new(state, clusters).print(&self.stdout, &self.style, self.json)
         } else {
-            state.print(&self.stdout, self.json)
+            state.print(&self.stdout, &self.style, self.json)
         }
     }
 
@@ -946,14 +943,14 @@ impl StateHub {
         self.api
             .get_all_states()
             .await
-            .print(&self.stdout, self.json)
+            .print(&self.stdout, &self.style, self.json)
     }
 
     async fn list_clusters(&self) -> anyhow::Result<()> {
         self.api
             .get_all_clusters()
             .await
-            .print(&self.stdout, self.json)
+            .print(&self.stdout, &self.style, self.json)
     }
 
     async fn interactive_register_cluster(
@@ -1028,9 +1025,9 @@ impl StateHub {
     async fn show_cluster(&self, name: v0::ClusterName) -> anyhow::Result<()> {
         let cluster = self.api.get_cluster(&name).await.map(Detailed)?;
         if let Ok(states) = self.api.get_all_states().await {
-            ClusterAndStates::new(cluster, states).print(&self.stdout, self.json)
+            ClusterAndStates::new(cluster, states).print(&self.stdout, &self.style, self.json)
         } else {
-            cluster.print(&self.stdout, self.json)
+            cluster.print(&self.stdout, &self.style, self.json)
         }
     }
 
@@ -1134,7 +1131,7 @@ impl StateHub {
             .create_volume(state_name, volume)
             .await
             .map(Quiet)
-            .print(&self.stdout, self.json)
+            .print(&self.stdout, &self.style, self.json)
     }
 
     async fn delete_volume(
@@ -1153,7 +1150,7 @@ impl StateHub {
                 self.delete_volume_helper(&state, &volume.name, wait)
                     .await
                     .map(Quiet)
-                    .print(&self.stdout, self.json)?;
+                    .print(&self.stdout, &self.style, self.json)?;
             }
         } else {
             self.verbosely("No such volume")?;
@@ -1170,14 +1167,14 @@ impl StateHub {
         self.api
             .set_volume_primary(state, volume, primary)
             .await
-            .print(&self.stdout, self.json)
+            .print(&self.stdout, &self.style, self.json)
     }
 
     async fn list_volumes(&self, state: v0::StateName) -> anyhow::Result<()> {
         self.api
             .get_all_volumes(state)
             .await
-            .print(&self.stdout, self.json)
+            .print(&self.stdout, &self.style, self.json)
     }
 
     async fn show_volumes(
@@ -1186,18 +1183,18 @@ impl StateHub {
         volumes: Vec<v0::VolumeName>,
     ) -> anyhow::Result<()> {
         if volumes.is_empty() {
-            self.api
-                .get_all_volumes(state)
-                .await
-                .map(Detailed)
-                .print(&self.stdout, self.json)
+            self.api.get_all_volumes(state).await.map(Detailed).print(
+                &self.stdout,
+                &self.style,
+                self.json,
+            )
         } else {
             for volume in volumes {
                 self.api
                     .get_volume(&state, &volume)
                     .await
                     .map(Detailed)
-                    .print(&self.stdout, self.json)?;
+                    .print(&self.stdout, &self.style, self.json)?;
             }
             Ok(())
         }
@@ -1216,7 +1213,7 @@ impl StateHub {
         self.api
             .set_owner(&state, &cluster)
             .await
-            .print(&self.stdout, self.json)
+            .print(&self.stdout, &self.style, self.json)
     }
 
     async fn unset_owner(
@@ -1230,7 +1227,7 @@ impl StateHub {
             self.api
                 .unset_owner(&state.name)
                 .await
-                .print(&self.stdout, self.json)
+                .print(&self.stdout, &self.style, self.json)
         } else {
             anyhow::bail!("Permission denied, you are not theowner of this state.")
         }
@@ -1307,7 +1304,7 @@ impl StateHub {
         namespace: String,
     ) -> anyhow::Result<()> {
         for kubectl in kubectls {
-            kubectl.install_statehub_cluster(&namespace, false).await?;
+            kubectl.install_statehub_cluster(&namespace).await?;
         }
 
         Ok(())
@@ -1331,7 +1328,7 @@ impl StateHub {
                     .collect::<HashMap<_, _>>()
             })
             .map(Output::from)
-            .print(&self.stdout, self.json)
+            .print(&self.stdout, &self.style, self.json)
     }
 
     async fn list_namespaces(&self, context: Option<String>) -> anyhow::Result<()> {
@@ -1416,7 +1413,8 @@ impl StateHub {
     }
 
     fn inform(&self, text: impl fmt::Display) -> io::Result<()> {
-        let text = text.to_string();
+        let text = format!("{}", self.style.apply_to(text));
+        // let text = text.to_string();
         if !text.is_empty() {
             self.stdout.write_line(&text)?;
         }
