@@ -24,7 +24,6 @@ pub(super) struct RegisterCluster {
     default_state: Option<String>,
     claim_unowned_states: bool,
     cleanup_grace: String,
-    install_state_crd: bool,
     azure: AzureCredentials,
 }
 
@@ -38,7 +37,6 @@ impl RegisterCluster {
         default_state: Option<String>,
         claim_unowned_states: bool,
         cleanup_grace: String,
-        install_state_crd: bool,
         azure: AzureCredentials,
     ) -> Self {
         Self {
@@ -49,7 +47,6 @@ impl RegisterCluster {
             default_state,
             claim_unowned_states,
             cleanup_grace,
-            install_state_crd,
             azure,
         }
     }
@@ -89,9 +86,7 @@ impl StateHub {
             locations.show(),
         ))?;
 
-        kubectl
-            .install_statehub_cluster(namespace, register_cluster.install_state_crd)
-            .await?;
+        kubectl.install_statehub_cluster(namespace).await?;
 
         self.setup_cluster_token_helper(&kubectl, &cluster, register_cluster)
             .await?;
@@ -113,7 +108,7 @@ impl StateHub {
         self.helm_install_helper(&kubectl, &cluster, register_cluster)
             .await?;
 
-        cluster.print(&self.stdout, self.json)
+        cluster.print(&self.stdout, &self.style, self.json)
     }
 
     pub(super) async fn unregister_cluster_helper(
@@ -126,7 +121,7 @@ impl StateHub {
         self.api
             .unregister_cluster(name)
             .await
-            .print(&self.stdout, self.json)?;
+            .print(&self.stdout, &self.style, self.json)?;
 
         kubectl.uninstall_statehub_cluster().await?;
         Ok(())
